@@ -1,4 +1,4 @@
-add_point_to_graph = function(
+add_point_to_graph <- function(
     graph,
     fit,
     name = "est.incidence",
@@ -8,15 +8,11 @@ add_point_to_graph = function(
         y = log_likelihood(.data$x, ...),
         label = "est.incidence"
       ),
-    ...
-)
-{
-
-  graph =
+    ...) {
+  graph <-
     graph +
     ggplot2::geom_point(
       data = point_data,
       ggplot2::aes(x = .data$x, y = .data$y, col = .data$label)
     )
-
 }
