@@ -18,8 +18,6 @@ strata <- function(x) {
 #' * `NULL` if `x` does not have a `"strata"` attribute
 #' @export
 #'
-strata.seroincidence.by = function(x)
-{
+strata.seroincidence.by <- function(x) {
   attr(x, "Strata")
 }
-
